@@ -22,7 +22,7 @@ def OpenCredentials(cred_path: str):
     return credentials
 
 
-def OpenSession(cred_path: str, region: str = 'us-east-2'):
+def OpenSession(cred_path: str = None, region: str = None):
     """
     TODO: Add docstring
 
@@ -41,7 +41,7 @@ def OpenSession(cred_path: str, region: str = 'us-east-2'):
         return boto3.session.Session()
 
 
-def OpenEC2Client(cred_path: str, region: str = 'us-east-2'):
+def OpenEC2Client(cred_path: str = None, region: str = None):
     """
     Open a boto3 EC2 resource using the specified credentials in the specified region
 
@@ -54,7 +54,7 @@ def OpenEC2Client(cred_path: str, region: str = 'us-east-2'):
     return ec2_client
 
 
-def OpenEC2Resource(cred_path: str, region: str = 'us-east-2'):
+def OpenEC2Resource(cred_path: str = None, region: str = None):
     """
     Open a boto3 EC2 resource using the specified credentials in the specified region
 
@@ -67,7 +67,7 @@ def OpenEC2Resource(cred_path: str, region: str = 'us-east-2'):
     return ec2_resource
 
 
-def OpenLambdaClient(cred_path: str, region: str = 'us-east-2'):
+def OpenLambdaClient(cred_path: str = None, region: str = None):
     """
     Open a boto3 Lambda client using the specified credentials in the specified region
 
@@ -80,7 +80,7 @@ def OpenLambdaClient(cred_path: str, region: str = 'us-east-2'):
     return lambda_client
 
 
-def OpenLambdaResource(cred_path: str, region: str = 'us-east-2'):
+def OpenLambdaResource(cred_path: str = None, region: str = None):
     """
     Open a boto3 Lambda resource using the specified credentials in the specified region
 
@@ -93,7 +93,7 @@ def OpenLambdaResource(cred_path: str, region: str = 'us-east-2'):
     return lambda_resource
 
 
-def OpenS3Client(cred_path: str, region: str = 'us-east-2'):
+def OpenS3Client(cred_path: str = None, region: str = None):
     """
     Open a boto3 S3 client using the specified credentials in the specified region
 
@@ -107,7 +107,7 @@ def OpenS3Client(cred_path: str, region: str = 'us-east-2'):
 
 
 class EC2_Client:
-    def __init__(self, cred_path: str, region: str = 'us-east-2'):
+    def __init__(self, cred_path: str = None, region: str = None):
         """
         Open a boto3 EC2 client using the specified credentials in the specified region
 
@@ -115,7 +115,10 @@ class EC2_Client:
         :param region: region to open the client in
         :return:
         """
-        self.client = OpenEC2Client(cred_path, region)
+        self.client = OpenEC2Client(
+            cred_path=cred_path,
+            region=region
+        )
 
     def GetDNS(self, instance_id: str):
         """
@@ -206,7 +209,7 @@ class EC2_Client:
 
 
 class Lambda_Client:
-    def __init__(self, cred_path: str, bucket_name: str, region: str = 'us-east-2'):
+    def __init__(self, bucket_name: str, cred_path: str = None, region: str = None):
         """
         Open a boto3 EC2 client using the specified credentials in the specified region
 
@@ -215,8 +218,14 @@ class Lambda_Client:
         :param region: region to open the client in
         :return:
         """
-        self.client = OpenLambdaClient(cred_path, region)
-        self.s3 = OpenS3Client(cred_path, region)
+        self.client = OpenLambdaClient(
+            cred_path=cred_path,
+            region=region
+        )
+        self.s3 = OpenS3Client(
+            cred_path=cred_path,
+            region=region
+        )
         self.bucket_name = bucket_name
 
     def UpdateLambda(self, lambda_name: str, zip_path: str, handler: str = ''):
