@@ -4,7 +4,7 @@ import zipfile
 
 def ZipFolder(folder_path: str):
     """
-    Compresses an entire folder into a zip archive of the same lambda_name
+    Compresses an entire folder into a zip archive of the same name
 
     :param folder_path: Path to the folder to be compressed
     :return: The path to the generated zip file
@@ -16,7 +16,7 @@ def ZipFolder(folder_path: str):
     for dir_path, dir_names, file_names in os.walk(folder_path):
         for file in file_names:
             file_path = '/'.join([dir_path, file])
-            zip_path = '/'.join(file_path.split('/')[1:])
+            zip_path = file_path.replace(folder_path, '')
             zip_file.write(file_path, arcname=zip_path)
     zip_file.close()
     return zip_file_path
